#!/bin/bash
#
# run_chef.sh - Runs chef on the host
#
# This is in its own script so that we can put this into the sudoers file and
# not require the deploy user to have sudo access for any chef-solo command

set -e

BUNDLE_FILE="$1"
CHEF_DIR="/opt/chef-repo"
CHEF_CONF="/etc/chef/client.rb"

if [[ ! -e "$BUNDLE_FILE" ]]; then
  echo "$BUNDLE_FILE does not exist!"
  exit 1
fi

if [[ -e $CHEF_DIR ]]; then
  rm -rf $CHEF_DIR
fi

function signature_fail {
  rm -rf $CHEF_DIR
  echo "Signature verification failed"
  exit 5
}

trap signature_fail ABRT

mkdir -p -m 700 $CHEF_DIR

cat /etc/ssl/private/encrypted_data_bag_secret.txt | \
  perl -pe 's/\n//' | \
  gpg --homedir /root/.gnupg --batch -d --passphrase-fd 0 "$BUNDLE_FILE" 2> \
  >( grep -q "Good signature from " || kill -ABRT $$ ) | \
  tar xj -C $CHEF_DIR

cd $CHEF_DIR || exit 2
chef-client -z -c $CHEF_CONF
